@@ -12,7 +12,7 @@ stream_hdlr = logging.StreamHandler()
 formatter = logging.Formatter('%(asctime)s %(levelname)s %(message)s')
 stream_hdlr.setFormatter(formatter)
 logger.addHandler(stream_hdlr)
-logger.setLevel(logging.WARN)
+logger.setLevel(logging.INFO)
 
 
 class Simulation:
@@ -81,7 +81,7 @@ class Simulation:
 		if bool_flag:
 			logger.setLevel(logging.DEBUG)
 		else:
-			logger.setLevel(logging.WARN)
+			logger.setLevel(logging.INFO)
 
 	def run(self):
 		if self.debug:
@@ -197,7 +197,7 @@ class Simulation:
 			if d2 > max_date:
 				d2 = max_date + datetime.timedelta(minutes=2) ##--## Is this needed?
 				last_iteration = True
-			logger.debug(f'===== From {d1} to {d2} ======')
+			logger.info(f'===== From {d1} to {d2} ======')
 			cur_recipients = pd.concat([
 										cur_recipients,
 										self.all_recipients.loc[(self.all_recipients.date > d1) & (self.all_recipients.date < d2)].copy()
